summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmimagemapedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmimagemapedit.h')
-rw-r--r--kpovmodeler/pmimagemapedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmimagemapedit.h b/kpovmodeler/pmimagemapedit.h
index 49ce3d8c..4b5d4b2e 100644
--- a/kpovmodeler/pmimagemapedit.h
+++ b/kpovmodeler/pmimagemapedit.h
@@ -45,12 +45,13 @@ class TQPushButton;
class PMImageMapEdit : public PMDialogEditBase
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMImageMapEdit with parent and name
*/
- PMImageMapEdit( TQWidget* parent, const char* name = 0 );
+ PMImageMapEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -45,12 +45,13 @@ class TQPushButton;
public:
/**
- * Creates a PMImageMapEdit with parent and name
+ * Creates a PMImageMapEdit with tqparent and name
*/